#[non_exhaustive]pub struct TrailingStop {
pub trail_by_ticks: i32,
pub trail_by_price_id: i32,
}Expand description
Configuration for trailing stop orders.
Used both by RithmicOrder::trailing_stop
for a standalone order and by
RithmicOcoOrderLeg::trailing_stop
for a single leg of an OCO group.
Example
use rithmic_rs::TrailingStop;
let trailing = TrailingStop::new()
.trail_by_ticks(20)
.trail_by_price_id(1)
.build()?;Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trail_by_ticks: i32Number of ticks to trail behind the market price
trail_by_price_id: i32Rithmic price-id to trail against. build() requires a non-zero id.
Implementations
Sourceimpl TrailingStop
impl TrailingStop
Sourcepub fn trail_by_ticks(self, trail_by_ticks: i32) -> Self
pub fn trail_by_ticks(self, trail_by_ticks: i32) -> Self
Number of ticks to trail behind the market price.
Sourcepub fn trail_by_price_id(self, trail_by_price_id: i32) -> Self
pub fn trail_by_price_id(self, trail_by_price_id: i32) -> Self
Rithmic price-id to trail against.
Sourcepub fn build(self) -> Result<Self, RithmicError>
pub fn build(self) -> Result<Self, RithmicError>
Requires both fields.