pub struct DepthByOrder {Show 19 fields
pub template_id: i32,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub sequence_number: Option<u64>,
pub update_type: Vec<i32>,
pub transaction_type: Vec<i32>,
pub depth_price: Vec<f64>,
pub prev_depth_price: Vec<f64>,
pub prev_depth_price_flag: Vec<bool>,
pub depth_size: Vec<i32>,
pub depth_order_priority: Vec<u64>,
pub exchange_order_id: Vec<String>,
pub ssboe: Option<i32>,
pub usecs: Option<i32>,
pub source_ssboe: Option<i32>,
pub source_usecs: Option<i32>,
pub source_nsecs: Option<i32>,
pub jop_ssboe: Option<i32>,
pub jop_nsecs: Option<i32>,
}Expand description
PB_OFFSET = 100000 , is the offset added for each MNM field id
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
symbol: Option<String>PB_OFFSET + MNM_SYMBOL
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
sequence_number: Option<u64>PB_OFFSET + MNM_SEQUENCE_NUMBER
update_type: Vec<i32>PB_OFFSET + MNM_UPDATE_TYPE
transaction_type: Vec<i32>PB_OFFSET + MNM_MARKET_DEPTH_SIDE
depth_price: Vec<f64>PB_OFFSET + MNM_MARKET_DEPTH_PRICE
prev_depth_price: Vec<f64>PB_OFFSET + MNM_PREVIOUS_MARKET_DEPTH_PRICE
prev_depth_price_flag: Vec<bool>PB_OFFSET + MNM_PREVIOUS_MARKET_DEPTH_PRICE_FLAG
depth_size: Vec<i32>PB_OFFSET + MNM_MARKET_DEPTH_SIZE
depth_order_priority: Vec<u64>PB_OFFSET + MNM_MARKET_DEPTH_ORDER_PRIORITY
exchange_order_id: Vec<String>PB_OFFSET + MNM_EXCH_ORD_ID
ssboe: Option<i32>PB_OFFSET + MNM_SECONDS_SINCE_BOE
usecs: Option<i32>PB_OFFSET + MNM_USECS
source_ssboe: Option<i32>PB_OFFSET + MNM_SOURCE_SSBOE
source_usecs: Option<i32>PB_OFFSET + MNM_SOURCE_USECS
source_nsecs: Option<i32>PB_OFFSET + MNM_SOURCE_NSECS
jop_ssboe: Option<i32>PB_OFFSET + MNM_JOP_SSBOE
jop_nsecs: Option<i32>PB_OFFSET + MNM_JOP_NSECS
Implementations
Sourceimpl DepthByOrder
impl DepthByOrder
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn update_type(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<UpdateType>>
pub fn update_type( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<UpdateType>>
Returns an iterator which yields the valid enum values contained in update_type.
Sourcepub fn push_update_type(&mut self, value: UpdateType)
pub fn push_update_type(&mut self, value: UpdateType)
Appends the provided enum value to update_type.
Sourcepub fn sequence_number(&self) -> u64
pub fn sequence_number(&self) -> u64
Returns the value of sequence_number, or the default value if sequence_number is unset.
Sourcepub fn source_ssboe(&self) -> i32
pub fn source_ssboe(&self) -> i32
Returns the value of source_ssboe, or the default value if source_ssboe is unset.
Sourcepub fn source_usecs(&self) -> i32
pub fn source_usecs(&self) -> i32
Returns the value of source_usecs, or the default value if source_usecs is unset.
Sourcepub fn source_nsecs(&self) -> i32
pub fn source_nsecs(&self) -> i32
Returns the value of source_nsecs, or the default value if source_nsecs is unset.
Sourcepub fn jop_ssboe(&self) -> i32
pub fn jop_ssboe(&self) -> i32
Returns the value of jop_ssboe, or the default value if jop_ssboe is unset.
Sourcepub fn jop_nsecs(&self) -> i32
pub fn jop_nsecs(&self) -> i32
Returns the value of jop_nsecs, or the default value if jop_nsecs is unset.
Sourcepub fn transaction_type(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TransactionType>>
pub fn transaction_type( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TransactionType>>
Returns an iterator which yields the valid enum values contained in transaction_type.
Sourcepub fn push_transaction_type(&mut self, value: TransactionType)
pub fn push_transaction_type(&mut self, value: TransactionType)
Appends the provided enum value to transaction_type.