InstrumentPnLPositionUpdate

Struct InstrumentPnLPositionUpdate 

pub struct InstrumentPnLPositionUpdate {
Show 33 fields pub template_id: i32, pub is_snapshot: Option<bool>, pub fcm_id: Option<String>, pub ib_id: Option<String>, pub account_id: Option<String>, pub symbol: Option<String>, pub exchange: Option<String>, pub product_code: Option<String>, pub instrument_type: Option<String>, pub fill_buy_qty: Option<i32>, pub fill_sell_qty: Option<i32>, pub order_buy_qty: Option<i32>, pub order_sell_qty: Option<i32>, pub buy_qty: Option<i32>, pub sell_qty: Option<i32>, pub avg_open_fill_price: Option<f64>, pub day_open_pnl: Option<f64>, pub day_closed_pnl: Option<f64>, pub day_pnl: Option<f64>, pub day_open_pnl_offset: Option<f64>, pub day_closed_pnl_offset: Option<f64>, pub mtm_security: Option<String>, pub open_long_options_value: Option<String>, pub open_short_options_value: Option<String>, pub closed_options_value: Option<String>, pub option_cash_reserved: Option<String>, pub open_position_pnl: Option<String>, pub open_position_quantity: Option<i32>, pub closed_position_pnl: Option<String>, pub closed_position_quantity: Option<i32>, pub net_quantity: Option<i32>, pub ssboe: Option<i32>, pub usecs: Option<i32>,
}

Fields

template_id: i32is_snapshot: Option<bool>fcm_id: Option<String>ib_id: Option<String>account_id: Option<String>symbol: Option<String>exchange: Option<String>product_code: Option<String>instrument_type: Option<String>fill_buy_qty: Option<i32>fill_sell_qty: Option<i32>order_buy_qty: Option<i32>order_sell_qty: Option<i32>buy_qty: Option<i32>sell_qty: Option<i32>avg_open_fill_price: Option<f64>day_open_pnl: Option<f64>day_closed_pnl: Option<f64>day_pnl: Option<f64>day_open_pnl_offset: Option<f64>day_closed_pnl_offset: Option<f64>mtm_security: Option<String>open_long_options_value: Option<String>open_short_options_value: Option<String>closed_options_value: Option<String>option_cash_reserved: Option<String>open_position_pnl: Option<String>open_position_quantity: Option<i32>closed_position_pnl: Option<String>closed_position_quantity: Option<i32>net_quantity: Option<i32>ssboe: Option<i32>usecs: Option<i32>

Implementations

Source

impl InstrumentPnLPositionUpdate

pub fn product_code(&self) -> &str

Returns the value of product_code, or the default value if product_code is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn instrument_type(&self) -> &str

Returns the value of instrument_type, or the default value if instrument_type is unset.

pub fn is_snapshot(&self) -> bool

Returns the value of is_snapshot, or the default value if is_snapshot is unset.

pub fn ssboe(&self) -> i32

Returns the value of ssboe, or the default value if ssboe is unset.

pub fn usecs(&self) -> i32

Returns the value of usecs, or the default value if usecs is unset.

pub fn account_id(&self) -> &str

Returns the value of account_id, or the default value if account_id is unset.

pub fn fcm_id(&self) -> &str

Returns the value of fcm_id, or the default value if fcm_id is unset.

pub fn ib_id(&self) -> &str

Returns the value of ib_id, or the default value if ib_id is unset.

pub fn order_buy_qty(&self) -> i32

Returns the value of order_buy_qty, or the default value if order_buy_qty is unset.

pub fn order_sell_qty(&self) -> i32

Returns the value of order_sell_qty, or the default value if order_sell_qty is unset.

pub fn fill_buy_qty(&self) -> i32

Returns the value of fill_buy_qty, or the default value if fill_buy_qty is unset.

pub fn fill_sell_qty(&self) -> i32

Returns the value of fill_sell_qty, or the default value if fill_sell_qty is unset.

pub fn buy_qty(&self) -> i32

Returns the value of buy_qty, or the default value if buy_qty is unset.

pub fn sell_qty(&self) -> i32

Returns the value of sell_qty, or the default value if sell_qty is unset.

pub fn mtm_security(&self) -> &str

Returns the value of mtm_security, or the default value if mtm_security is unset.

pub fn avg_open_fill_price(&self) -> f64

Returns the value of avg_open_fill_price, or the default value if avg_open_fill_price is unset.

pub fn open_position_pnl(&self) -> &str

Returns the value of open_position_pnl, or the default value if open_position_pnl is unset.

pub fn open_position_quantity(&self) -> i32

Returns the value of open_position_quantity, or the default value if open_position_quantity is unset.

pub fn closed_position_pnl(&self) -> &str

Returns the value of closed_position_pnl, or the default value if closed_position_pnl is unset.

pub fn closed_position_quantity(&self) -> i32

Returns the value of closed_position_quantity, or the default value if closed_position_quantity is unset.

pub fn net_quantity(&self) -> i32

Returns the value of net_quantity, or the default value if net_quantity is unset.

pub fn open_long_options_value(&self) -> &str

Returns the value of open_long_options_value, or the default value if open_long_options_value is unset.

pub fn open_short_options_value(&self) -> &str

Returns the value of open_short_options_value, or the default value if open_short_options_value is unset.

pub fn closed_options_value(&self) -> &str

Returns the value of closed_options_value, or the default value if closed_options_value is unset.

pub fn option_cash_reserved(&self) -> &str

Returns the value of option_cash_reserved, or the default value if option_cash_reserved is unset.

pub fn day_open_pnl(&self) -> f64

Returns the value of day_open_pnl, or the default value if day_open_pnl is unset.

pub fn day_closed_pnl(&self) -> f64

Returns the value of day_closed_pnl, or the default value if day_closed_pnl is unset.

pub fn day_pnl(&self) -> f64

Returns the value of day_pnl, or the default value if day_pnl is unset.

pub fn day_open_pnl_offset(&self) -> f64

Returns the value of day_open_pnl_offset, or the default value if day_open_pnl_offset is unset.

pub fn day_closed_pnl_offset(&self) -> f64

Returns the value of day_closed_pnl_offset, or the default value if day_closed_pnl_offset is unset.