OpenInterest

Struct OpenInterest 

pub struct OpenInterest {
    pub template_id: i32,
    pub symbol: Option<String>,
    pub exchange: Option<String>,
    pub is_snapshot: Option<bool>,
    pub should_clear: Option<bool>,
    pub open_interest: Option<u64>,
    pub ssboe: Option<i32>,
    pub usecs: Option<i32>,
}
PB_OFFSET = 100000, is the offset added for each MNM field id

Fields

template_id: i32

PB_OFFSET + MNM_TEMPLATE_ID

symbol: Option<String>

PB_OFFSET + MNM_SYMBOL

exchange: Option<String>

PB_OFFSET + MNM_EXCHANGE

is_snapshot: Option<bool>

PB_OFFSET + MNM_UPDATE_TYPE

should_clear: Option<bool>

PB_OFFSET + MNM_DISPLAY_INDICATOR

open_interest: Option<u64>

PB_OFFSET + MNM_OPEN_INTEREST

ssboe: Option<i32>

PB_OFFSET + MNM_SECONDS_SINCE_BOE

usecs: Option<i32>

PB_OFFSET + MNM_USECS

Implementations

Source

impl OpenInterest

pub fn open_interest(&self) -> u64

Returns the value of open_interest, or the default value if open_interest is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn is_snapshot(&self) -> bool

Returns the value of is_snapshot, or the default value if is_snapshot is unset.

pub fn ssboe(&self) -> i32

Returns the value of ssboe, or the default value if ssboe is unset.

pub fn usecs(&self) -> i32

Returns the value of usecs, or the default value if usecs is unset.

pub fn should_clear(&self) -> bool

Returns the value of should_clear, or the default value if should_clear is unset.