pub struct QuoteStatistics {
pub template_id: i32,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub presence_bits: Option<u32>,
pub clear_bits: Option<u32>,
pub is_snapshot: Option<bool>,
pub highest_bid_price: Option<f64>,
pub lowest_ask_price: Option<f64>,
pub ssboe: Option<i32>,
pub usecs: Option<i32>,
}Expand description
PB_OFFSET = 100000, is the offset added for each MNM field id
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
symbol: Option<String>PB_OFFSET + MNM_SYMBOL
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
presence_bits: Option<u32>PB_OFFSET + MNM_PRICING_INDICATOR
clear_bits: Option<u32>PB_OFFSET + MNM_DISPLAY_INDICATOR
is_snapshot: Option<bool>PB_OFFSET + MNM_UPDATE_TYPE
highest_bid_price: Option<f64>PB_OFFSET + MNM_HIGHEST_BID_PRICE
lowest_ask_price: Option<f64>PB_OFFSET + MNM_LOWEST_ASK_PRICE
ssboe: Option<i32>PB_OFFSET + MNM_SECONDS_SINCE_BOE
usecs: Option<i32>PB_OFFSET + MNM_USECS
Implementations
Sourceimpl QuoteStatistics
impl QuoteStatistics
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn is_snapshot(&self) -> bool
pub fn is_snapshot(&self) -> bool
Returns the value of is_snapshot, or the default value if is_snapshot is unset.
Sourcepub fn presence_bits(&self) -> u32
pub fn presence_bits(&self) -> u32
Returns the value of presence_bits, or the default value if presence_bits is unset.
Sourcepub fn highest_bid_price(&self) -> f64
pub fn highest_bid_price(&self) -> f64
Returns the value of highest_bid_price, or the default value if highest_bid_price is unset.
Sourcepub fn lowest_ask_price(&self) -> f64
pub fn lowest_ask_price(&self) -> f64
Returns the value of lowest_ask_price, or the default value if lowest_ask_price is unset.
Sourcepub fn clear_bits(&self) -> u32
pub fn clear_bits(&self) -> u32
Returns the value of clear_bits, or the default value if clear_bits is unset.