pub struct RequestBracketOrder {Show 44 fields
pub template_id: i32,
pub user_msg: Vec<String>,
pub user_tag: Option<String>,
pub window_name: Option<String>,
pub fcm_id: Option<String>,
pub ib_id: Option<String>,
pub account_id: Option<String>,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub quantity: Option<i32>,
pub price: Option<f64>,
pub trigger_price: Option<f64>,
pub transaction_type: Option<i32>,
pub duration: Option<i32>,
pub price_type: Option<i32>,
pub trade_route: Option<String>,
pub manual_or_auto: Option<i32>,
pub user_type: Option<i32>,
pub bracket_type: Option<i32>,
pub break_even_ticks: Option<i32>,
pub break_even_trigger_ticks: Option<i32>,
pub target_quantity: Vec<i32>,
pub target_ticks: Vec<i32>,
pub stop_quantity: Vec<i32>,
pub stop_ticks: Vec<i32>,
pub trailing_stop_trigger_ticks: Option<i32>,
pub trailing_stop_by_last_trade_price: Option<bool>,
pub target_market_order_if_touched: Option<bool>,
pub stop_market_on_reject: Option<bool>,
pub target_market_at_ssboe: Option<i32>,
pub target_market_at_usecs: Option<i32>,
pub stop_market_at_ssboe: Option<i32>,
pub stop_market_at_usecs: Option<i32>,
pub target_market_order_after_secs: Option<i32>,
pub release_at_ssboe: Option<i32>,
pub release_at_usecs: Option<i32>,
pub cancel_at_ssboe: Option<i32>,
pub cancel_at_usecs: Option<i32>,
pub cancel_after_secs: Option<i32>,
pub if_touched_symbol: Option<String>,
pub if_touched_exchange: Option<String>,
pub if_touched_condition: Option<i32>,
pub if_touched_price_field: Option<i32>,
pub if_touched_price: Option<f64>,
}Fields
template_id: i32user_msg: Vec<String>user_tag: Option<String>window_name: Option<String>fcm_id: Option<String>ib_id: Option<String>account_id: Option<String>symbol: Option<String>exchange: Option<String>quantity: Option<i32>price: Option<f64>trigger_price: Option<f64>transaction_type: Option<i32>duration: Option<i32>price_type: Option<i32>trade_route: Option<String>manual_or_auto: Option<i32>user_type: Option<i32>bracket_type: Option<i32>break_even_ticks: Option<i32>break_even_trigger_ticks: Option<i32>target_quantity: Vec<i32>target_ticks: Vec<i32>stop_quantity: Vec<i32>stop_ticks: Vec<i32>trailing_stop_trigger_ticks: Option<i32>trailing_stop_by_last_trade_price: Option<bool>target_market_order_if_touched: Option<bool>stop_market_on_reject: Option<bool>target_market_at_ssboe: Option<i32>target_market_at_usecs: Option<i32>stop_market_at_ssboe: Option<i32>stop_market_at_usecs: Option<i32>target_market_order_after_secs: Option<i32>release_at_ssboe: Option<i32>release_at_usecs: Option<i32>cancel_at_ssboe: Option<i32>cancel_at_usecs: Option<i32>cancel_after_secs: Option<i32>if_touched_symbol: Option<String>if_touched_exchange: Option<String>if_touched_condition: Option<i32>if_touched_price_field: Option<i32>if_touched_price: Option<f64>Implementations
Sourceimpl RequestBracketOrder
impl RequestBracketOrder
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn transaction_type(&self) -> TransactionType
pub fn transaction_type(&self) -> TransactionType
Returns the enum value of transaction_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_transaction_type(&mut self, value: TransactionType)
pub fn set_transaction_type(&mut self, value: TransactionType)
Sets transaction_type to the provided enum value.
Sourcepub fn quantity(&self) -> i32
pub fn quantity(&self) -> i32
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn duration(&self) -> Duration
pub fn duration(&self) -> Duration
Returns the enum value of duration, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_duration(&mut self, value: Duration)
pub fn set_duration(&mut self, value: Duration)
Sets duration to the provided enum value.
Sourcepub fn price_type(&self) -> PriceType
pub fn price_type(&self) -> PriceType
Returns the enum value of price_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_price_type(&mut self, value: PriceType)
pub fn set_price_type(&mut self, value: PriceType)
Sets price_type to the provided enum value.
Sourcepub fn trade_route(&self) -> &str
pub fn trade_route(&self) -> &str
Returns the value of trade_route, or the default value if trade_route is unset.
Sourcepub fn trigger_price(&self) -> f64
pub fn trigger_price(&self) -> f64
Returns the value of trigger_price, or the default value if trigger_price is unset.
Sourcepub fn if_touched_price(&self) -> f64
pub fn if_touched_price(&self) -> f64
Returns the value of if_touched_price, or the default value if if_touched_price is unset.
Sourcepub fn account_id(&self) -> &str
pub fn account_id(&self) -> &str
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn fcm_id(&self) -> &str
pub fn fcm_id(&self) -> &str
Returns the value of fcm_id, or the default value if fcm_id is unset.
Sourcepub fn ib_id(&self) -> &str
pub fn ib_id(&self) -> &str
Returns the value of ib_id, or the default value if ib_id is unset.
Sourcepub fn user_type(&self) -> UserType
pub fn user_type(&self) -> UserType
Returns the enum value of user_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_user_type(&mut self, value: UserType)
pub fn set_user_type(&mut self, value: UserType)
Sets user_type to the provided enum value.
Sourcepub fn user_tag(&self) -> &str
pub fn user_tag(&self) -> &str
Returns the value of user_tag, or the default value if user_tag is unset.
Sourcepub fn if_touched_symbol(&self) -> &str
pub fn if_touched_symbol(&self) -> &str
Returns the value of if_touched_symbol, or the default value if if_touched_symbol is unset.
Sourcepub fn if_touched_exchange(&self) -> &str
pub fn if_touched_exchange(&self) -> &str
Returns the value of if_touched_exchange, or the default value if if_touched_exchange is unset.
Sourcepub fn if_touched_condition(&self) -> Condition
pub fn if_touched_condition(&self) -> Condition
Returns the enum value of if_touched_condition, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_if_touched_condition(&mut self, value: Condition)
pub fn set_if_touched_condition(&mut self, value: Condition)
Sets if_touched_condition to the provided enum value.
Sourcepub fn if_touched_price_field(&self) -> PriceField
pub fn if_touched_price_field(&self) -> PriceField
Returns the enum value of if_touched_price_field, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_if_touched_price_field(&mut self, value: PriceField)
pub fn set_if_touched_price_field(&mut self, value: PriceField)
Sets if_touched_price_field to the provided enum value.
Sourcepub fn release_at_ssboe(&self) -> i32
pub fn release_at_ssboe(&self) -> i32
Returns the value of release_at_ssboe, or the default value if release_at_ssboe is unset.
Sourcepub fn cancel_after_secs(&self) -> i32
pub fn cancel_after_secs(&self) -> i32
Returns the value of cancel_after_secs, or the default value if cancel_after_secs is unset.
Sourcepub fn release_at_usecs(&self) -> i32
pub fn release_at_usecs(&self) -> i32
Returns the value of release_at_usecs, or the default value if release_at_usecs is unset.
Sourcepub fn window_name(&self) -> &str
pub fn window_name(&self) -> &str
Returns the value of window_name, or the default value if window_name is unset.
Sourcepub fn manual_or_auto(&self) -> OrderPlacement
pub fn manual_or_auto(&self) -> OrderPlacement
Returns the enum value of manual_or_auto, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_manual_or_auto(&mut self, value: OrderPlacement)
pub fn set_manual_or_auto(&mut self, value: OrderPlacement)
Sets manual_or_auto to the provided enum value.
Sourcepub fn stop_market_on_reject(&self) -> bool
pub fn stop_market_on_reject(&self) -> bool
Returns the value of stop_market_on_reject, or the default value if stop_market_on_reject is unset.
Sourcepub fn trailing_stop_by_last_trade_price(&self) -> bool
pub fn trailing_stop_by_last_trade_price(&self) -> bool
Returns the value of trailing_stop_by_last_trade_price, or the default value if trailing_stop_by_last_trade_price is unset.
Sourcepub fn cancel_at_ssboe(&self) -> i32
pub fn cancel_at_ssboe(&self) -> i32
Returns the value of cancel_at_ssboe, or the default value if cancel_at_ssboe is unset.
Sourcepub fn cancel_at_usecs(&self) -> i32
pub fn cancel_at_usecs(&self) -> i32
Returns the value of cancel_at_usecs, or the default value if cancel_at_usecs is unset.
Sourcepub fn bracket_type(&self) -> BracketType
pub fn bracket_type(&self) -> BracketType
Returns the enum value of bracket_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_bracket_type(&mut self, value: BracketType)
pub fn set_bracket_type(&mut self, value: BracketType)
Sets bracket_type to the provided enum value.
Sourcepub fn trailing_stop_trigger_ticks(&self) -> i32
pub fn trailing_stop_trigger_ticks(&self) -> i32
Returns the value of trailing_stop_trigger_ticks, or the default value if trailing_stop_trigger_ticks is unset.
Sourcepub fn target_market_at_ssboe(&self) -> i32
pub fn target_market_at_ssboe(&self) -> i32
Returns the value of target_market_at_ssboe, or the default value if target_market_at_ssboe is unset.
Sourcepub fn target_market_at_usecs(&self) -> i32
pub fn target_market_at_usecs(&self) -> i32
Returns the value of target_market_at_usecs, or the default value if target_market_at_usecs is unset.
Sourcepub fn stop_market_at_ssboe(&self) -> i32
pub fn stop_market_at_ssboe(&self) -> i32
Returns the value of stop_market_at_ssboe, or the default value if stop_market_at_ssboe is unset.
Sourcepub fn stop_market_at_usecs(&self) -> i32
pub fn stop_market_at_usecs(&self) -> i32
Returns the value of stop_market_at_usecs, or the default value if stop_market_at_usecs is unset.
Sourcepub fn target_market_order_after_secs(&self) -> i32
pub fn target_market_order_after_secs(&self) -> i32
Returns the value of target_market_order_after_secs, or the default value if target_market_order_after_secs is unset.
Sourcepub fn target_market_order_if_touched(&self) -> bool
pub fn target_market_order_if_touched(&self) -> bool
Returns the value of target_market_order_if_touched, or the default value if target_market_order_if_touched is unset.
Sourcepub fn break_even_ticks(&self) -> i32
pub fn break_even_ticks(&self) -> i32
Returns the value of break_even_ticks, or the default value if break_even_ticks is unset.
Sourcepub fn break_even_trigger_ticks(&self) -> i32
pub fn break_even_trigger_ticks(&self) -> i32
Returns the value of break_even_trigger_ticks, or the default value if break_even_trigger_ticks is unset.