pub struct RequestDepthByOrderUpdates {
pub template_id: i32,
pub user_msg: Vec<String>,
pub request: Option<i32>,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub depth_price: Option<f64>,
}Expand description
PB_OFFSET = 100000, is the offset added for each MNM field id
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
user_msg: Vec<String>PB_OFFSET + MNM_USER_MSG
request: Option<i32>PB_OFFSET + MNM_REQUEST
symbol: Option<String>PB_OFFSET + MNM_SYMBOL
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
depth_price: Option<f64>PB_OFFSET + MNM_MARKET_DEPTH_PRICE
Implementations
Sourceimpl RequestDepthByOrderUpdates
impl RequestDepthByOrderUpdates
Sourcepub fn request(&self) -> Request
pub fn request(&self) -> Request
Returns the enum value of request, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_request(&mut self, value: Request)
pub fn set_request(&mut self, value: Request)
Sets request to the provided enum value.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn depth_price(&self) -> f64
pub fn depth_price(&self) -> f64
Returns the value of depth_price, or the default value if depth_price is unset.