RequestExitPosition

Struct RequestExitPosition 

pub struct RequestExitPosition {
    pub template_id: i32,
    pub user_msg: Vec<String>,
    pub window_name: Option<String>,
    pub fcm_id: Option<String>,
    pub ib_id: Option<String>,
    pub account_id: Option<String>,
    pub symbol: Option<String>,
    pub exchange: Option<String>,
    pub trading_algorithm: Option<String>,
    pub manual_or_auto: Option<i32>,
}

Fields

template_id: i32user_msg: Vec<String>window_name: Option<String>fcm_id: Option<String>ib_id: Option<String>account_id: Option<String>symbol: Option<String>

optional field, if set, exchange field should also be set.

exchange: Option<String>

optional field, if set, symbol field should also be set.

trading_algorithm: Option<String>

optional field

manual_or_auto: Option<i32>

required field

Implementations

Source

impl RequestExitPosition

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn account_id(&self) -> &str

Returns the value of account_id, or the default value if account_id is unset.

pub fn fcm_id(&self) -> &str

Returns the value of fcm_id, or the default value if fcm_id is unset.

pub fn ib_id(&self) -> &str

Returns the value of ib_id, or the default value if ib_id is unset.

pub fn window_name(&self) -> &str

Returns the value of window_name, or the default value if window_name is unset.

pub fn trading_algorithm(&self) -> &str

Returns the value of trading_algorithm, or the default value if trading_algorithm is unset.

pub fn manual_or_auto(&self) -> OrderPlacement

Returns the enum value of manual_or_auto, or the default if the field is unset or set to an invalid enum value.

pub fn set_manual_or_auto(&mut self, value: OrderPlacement)

Sets manual_or_auto to the provided enum value.