RequestLogin

Struct RequestLogin 

pub struct RequestLogin {
Show 13 fields pub template_id: i32, pub template_version: Option<String>, pub user_msg: Vec<String>, pub user: Option<String>, pub password: Option<String>, pub app_name: Option<String>, pub app_version: Option<String>, pub system_name: Option<String>, pub infra_type: Option<i32>, pub mac_addr: Vec<String>, pub os_version: Option<String>, pub os_platform: Option<String>, pub aggregated_quotes: Option<bool>,
}

Fields

template_id: i32template_version: Option<String>user_msg: Vec<String>user: Option<String>password: Option<String>app_name: Option<String>app_version: Option<String>system_name: Option<String>infra_type: Option<i32>mac_addr: Vec<String>os_version: Option<String>os_platform: Option<String>aggregated_quotes: Option<bool>

applicable only for TICKER_PLANT infra_type

Implementations

Source

impl RequestLogin

pub fn app_name(&self) -> &str

Returns the value of app_name, or the default value if app_name is unset.

pub fn password(&self) -> &str

Returns the value of password, or the default value if password is unset.

pub fn user(&self) -> &str

Returns the value of user, or the default value if user is unset.

pub fn app_version(&self) -> &str

Returns the value of app_version, or the default value if app_version is unset.

pub fn os_platform(&self) -> &str

Returns the value of os_platform, or the default value if os_platform is unset.

pub fn os_version(&self) -> &str

Returns the value of os_version, or the default value if os_version is unset.

pub fn infra_type(&self) -> SysInfraType

Returns the enum value of infra_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_infra_type(&mut self, value: SysInfraType)

Sets infra_type to the provided enum value.

pub fn system_name(&self) -> &str

Returns the value of system_name, or the default value if system_name is unset.

pub fn template_version(&self) -> &str

Returns the value of template_version, or the default value if template_version is unset.

pub fn aggregated_quotes(&self) -> bool

Returns the value of aggregated_quotes, or the default value if aggregated_quotes is unset.