pub struct RequestMarketDataUpdateByUnderlying {
pub template_id: i32,
pub user_msg: Vec<String>,
pub underlying_symbol: Option<String>,
pub exchange: Option<String>,
pub expiration_date: Option<String>,
pub request: Option<i32>,
pub update_bits: Option<u32>,
}Expand description
update bits and Request enum field defined here is an exact copy of request_market_data_update.proto Make sure they are always the same in both proto files.
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
user_msg: Vec<String>PB_OFFSET + MNM_USER_MSG
underlying_symbol: Option<String>PB_OFFSET + MNM_UNDERLYING_SYMBOL
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
expiration_date: Option<String>PB_OFFSET + MNM_EXPIRATION_DATE
request: Option<i32>PB_OFFSET + MNM_REQUEST
update_bits: Option<u32>PB_OFFSET + MNM_MESSAGE_ID
Implementations
Sourceimpl RequestMarketDataUpdateByUnderlying
impl RequestMarketDataUpdateByUnderlying
Sourcepub fn request(&self) -> Request
pub fn request(&self) -> Request
Returns the enum value of request, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_request(&mut self, value: Request)
pub fn set_request(&mut self, value: Request)
Sets request to the provided enum value.
Sourcepub fn expiration_date(&self) -> &str
pub fn expiration_date(&self) -> &str
Returns the value of expiration_date, or the default value if expiration_date is unset.
Sourcepub fn underlying_symbol(&self) -> &str
pub fn underlying_symbol(&self) -> &str
Returns the value of underlying_symbol, or the default value if underlying_symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn update_bits(&self) -> u32
pub fn update_bits(&self) -> u32
Returns the value of update_bits, or the default value if update_bits is unset.