pub struct RequestModifyOrder {Show 21 fields
pub template_id: i32,
pub user_msg: Vec<String>,
pub window_name: Option<String>,
pub fcm_id: Option<String>,
pub ib_id: Option<String>,
pub account_id: Option<String>,
pub basket_id: Option<String>,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub quantity: Option<i32>,
pub price: Option<f64>,
pub trigger_price: Option<f64>,
pub price_type: Option<i32>,
pub manual_or_auto: Option<i32>,
pub trailing_stop: Option<bool>,
pub trail_by_ticks: Option<i32>,
pub if_touched_symbol: Option<String>,
pub if_touched_exchange: Option<String>,
pub if_touched_condition: Option<i32>,
pub if_touched_price_field: Option<i32>,
pub if_touched_price: Option<f64>,
}Fields
template_id: i32user_msg: Vec<String>window_name: Option<String>fcm_id: Option<String>ib_id: Option<String>account_id: Option<String>basket_id: Option<String>symbol: Option<String>exchange: Option<String>quantity: Option<i32>price: Option<f64>trigger_price: Option<f64>price_type: Option<i32>manual_or_auto: Option<i32>trailing_stop: Option<bool>trail_by_ticks: Option<i32>if_touched_symbol: Option<String>if_touched_exchange: Option<String>if_touched_condition: Option<i32>if_touched_price_field: Option<i32>if_touched_price: Option<f64>Implementations
Sourceimpl RequestModifyOrder
impl RequestModifyOrder
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn basket_id(&self) -> &str
pub fn basket_id(&self) -> &str
Returns the value of basket_id, or the default value if basket_id is unset.
Sourcepub fn quantity(&self) -> i32
pub fn quantity(&self) -> i32
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn price_type(&self) -> PriceType
pub fn price_type(&self) -> PriceType
Returns the enum value of price_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_price_type(&mut self, value: PriceType)
pub fn set_price_type(&mut self, value: PriceType)
Sets price_type to the provided enum value.
Sourcepub fn trigger_price(&self) -> f64
pub fn trigger_price(&self) -> f64
Returns the value of trigger_price, or the default value if trigger_price is unset.
Sourcepub fn if_touched_price(&self) -> f64
pub fn if_touched_price(&self) -> f64
Returns the value of if_touched_price, or the default value if if_touched_price is unset.
Sourcepub fn account_id(&self) -> &str
pub fn account_id(&self) -> &str
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn fcm_id(&self) -> &str
pub fn fcm_id(&self) -> &str
Returns the value of fcm_id, or the default value if fcm_id is unset.
Sourcepub fn ib_id(&self) -> &str
pub fn ib_id(&self) -> &str
Returns the value of ib_id, or the default value if ib_id is unset.
Sourcepub fn if_touched_symbol(&self) -> &str
pub fn if_touched_symbol(&self) -> &str
Returns the value of if_touched_symbol, or the default value if if_touched_symbol is unset.
Sourcepub fn if_touched_exchange(&self) -> &str
pub fn if_touched_exchange(&self) -> &str
Returns the value of if_touched_exchange, or the default value if if_touched_exchange is unset.
Sourcepub fn if_touched_condition(&self) -> Condition
pub fn if_touched_condition(&self) -> Condition
Returns the enum value of if_touched_condition, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_if_touched_condition(&mut self, value: Condition)
pub fn set_if_touched_condition(&mut self, value: Condition)
Sets if_touched_condition to the provided enum value.
Sourcepub fn if_touched_price_field(&self) -> PriceField
pub fn if_touched_price_field(&self) -> PriceField
Returns the enum value of if_touched_price_field, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_if_touched_price_field(&mut self, value: PriceField)
pub fn set_if_touched_price_field(&mut self, value: PriceField)
Sets if_touched_price_field to the provided enum value.
Sourcepub fn window_name(&self) -> &str
pub fn window_name(&self) -> &str
Returns the value of window_name, or the default value if window_name is unset.
Sourcepub fn manual_or_auto(&self) -> OrderPlacement
pub fn manual_or_auto(&self) -> OrderPlacement
Returns the enum value of manual_or_auto, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_manual_or_auto(&mut self, value: OrderPlacement)
pub fn set_manual_or_auto(&mut self, value: OrderPlacement)
Sets manual_or_auto to the provided enum value.
Sourcepub fn trailing_stop(&self) -> bool
pub fn trailing_stop(&self) -> bool
Returns the value of trailing_stop, or the default value if trailing_stop is unset.
Sourcepub fn trail_by_ticks(&self) -> i32
pub fn trail_by_ticks(&self) -> i32
Returns the value of trail_by_ticks, or the default value if trail_by_ticks is unset.