RequestNewOrder

Struct RequestNewOrder 

pub struct RequestNewOrder {
Show 30 fields pub template_id: i32, pub user_msg: Vec<String>, pub user_tag: Option<String>, pub window_name: Option<String>, pub fcm_id: Option<String>, pub ib_id: Option<String>, pub account_id: Option<String>, pub symbol: Option<String>, pub exchange: Option<String>, pub quantity: Option<i32>, pub price: Option<f64>, pub trigger_price: Option<f64>, pub transaction_type: Option<i32>, pub duration: Option<i32>, pub price_type: Option<i32>, pub trade_route: Option<String>, pub manual_or_auto: Option<i32>, pub trailing_stop: Option<bool>, pub trail_by_ticks: Option<i32>, pub trail_by_price_id: Option<i32>, pub release_at_ssboe: Option<i32>, pub release_at_usecs: Option<i32>, pub cancel_at_ssboe: Option<i32>, pub cancel_at_usecs: Option<i32>, pub cancel_after_secs: Option<i32>, pub if_touched_symbol: Option<String>, pub if_touched_exchange: Option<String>, pub if_touched_condition: Option<i32>, pub if_touched_price_field: Option<i32>, pub if_touched_price: Option<f64>,
}

Fields

template_id: i32user_msg: Vec<String>user_tag: Option<String>window_name: Option<String>fcm_id: Option<String>ib_id: Option<String>account_id: Option<String>symbol: Option<String>exchange: Option<String>quantity: Option<i32>price: Option<f64>trigger_price: Option<f64>transaction_type: Option<i32>duration: Option<i32>price_type: Option<i32>trade_route: Option<String>manual_or_auto: Option<i32>trailing_stop: Option<bool>trail_by_ticks: Option<i32>trail_by_price_id: Option<i32>release_at_ssboe: Option<i32>release_at_usecs: Option<i32>cancel_at_ssboe: Option<i32>cancel_at_usecs: Option<i32>cancel_after_secs: Option<i32>if_touched_symbol: Option<String>if_touched_exchange: Option<String>if_touched_condition: Option<i32>if_touched_price_field: Option<i32>if_touched_price: Option<f64>

Implementations

Source

impl RequestNewOrder

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn transaction_type(&self) -> TransactionType

Returns the enum value of transaction_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_transaction_type(&mut self, value: TransactionType)

Sets transaction_type to the provided enum value.

pub fn quantity(&self) -> i32

Returns the value of quantity, or the default value if quantity is unset.

pub fn duration(&self) -> Duration

Returns the enum value of duration, or the default if the field is unset or set to an invalid enum value.

pub fn set_duration(&mut self, value: Duration)

Sets duration to the provided enum value.

pub fn price_type(&self) -> PriceType

Returns the enum value of price_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_price_type(&mut self, value: PriceType)

Sets price_type to the provided enum value.

pub fn trade_route(&self) -> &str

Returns the value of trade_route, or the default value if trade_route is unset.

pub fn trigger_price(&self) -> f64

Returns the value of trigger_price, or the default value if trigger_price is unset.

pub fn if_touched_price(&self) -> f64

Returns the value of if_touched_price, or the default value if if_touched_price is unset.

pub fn account_id(&self) -> &str

Returns the value of account_id, or the default value if account_id is unset.

pub fn fcm_id(&self) -> &str

Returns the value of fcm_id, or the default value if fcm_id is unset.

pub fn ib_id(&self) -> &str

Returns the value of ib_id, or the default value if ib_id is unset.

pub fn user_tag(&self) -> &str

Returns the value of user_tag, or the default value if user_tag is unset.

pub fn if_touched_symbol(&self) -> &str

Returns the value of if_touched_symbol, or the default value if if_touched_symbol is unset.

pub fn if_touched_exchange(&self) -> &str

Returns the value of if_touched_exchange, or the default value if if_touched_exchange is unset.

pub fn if_touched_condition(&self) -> Condition

Returns the enum value of if_touched_condition, or the default if the field is unset or set to an invalid enum value.

pub fn set_if_touched_condition(&mut self, value: Condition)

Sets if_touched_condition to the provided enum value.

pub fn if_touched_price_field(&self) -> PriceField

Returns the enum value of if_touched_price_field, or the default if the field is unset or set to an invalid enum value.

pub fn set_if_touched_price_field(&mut self, value: PriceField)

Sets if_touched_price_field to the provided enum value.

pub fn release_at_ssboe(&self) -> i32

Returns the value of release_at_ssboe, or the default value if release_at_ssboe is unset.

pub fn cancel_after_secs(&self) -> i32

Returns the value of cancel_after_secs, or the default value if cancel_after_secs is unset.

pub fn release_at_usecs(&self) -> i32

Returns the value of release_at_usecs, or the default value if release_at_usecs is unset.

pub fn window_name(&self) -> &str

Returns the value of window_name, or the default value if window_name is unset.

pub fn manual_or_auto(&self) -> OrderPlacement

Returns the enum value of manual_or_auto, or the default if the field is unset or set to an invalid enum value.

pub fn set_manual_or_auto(&mut self, value: OrderPlacement)

Sets manual_or_auto to the provided enum value.

pub fn trailing_stop(&self) -> bool

Returns the value of trailing_stop, or the default value if trailing_stop is unset.

pub fn trail_by_ticks(&self) -> i32

Returns the value of trail_by_ticks, or the default value if trail_by_ticks is unset.

pub fn trail_by_price_id(&self) -> i32

Returns the value of trail_by_price_id, or the default value if trail_by_price_id is unset.

pub fn cancel_at_ssboe(&self) -> i32

Returns the value of cancel_at_ssboe, or the default value if cancel_at_ssboe is unset.

pub fn cancel_at_usecs(&self) -> i32

Returns the value of cancel_at_usecs, or the default value if cancel_at_usecs is unset.