pub struct RequestTickBarUpdate {
pub template_id: i32,
pub user_msg: Vec<String>,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub request: Option<i32>,
pub bar_type: Option<i32>,
pub bar_sub_type: Option<i32>,
pub bar_type_specifier: Option<String>,
pub custom_session_open_ssm: Option<i32>,
pub custom_session_close_ssm: Option<i32>,
}Expand description
PB_OFFSET = 100000, is the offset added for each MNM field id
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
user_msg: Vec<String>PB_OFFSET + MNM_USER_MSG
symbol: Option<String>PB_OFFSET + MNM_SYMBOL
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
request: Option<i32>PB_OFFSET + MNM_REQUEST
bar_type: Option<i32>PB_OFFSET + MNM_DATA_BAR_TYPE
bar_sub_type: Option<i32>PB_OFFSET + MNM_DATA_BAR_SUB_TYPE
bar_type_specifier: Option<String>PB_OFFSET + MNM_CATEGORY_SPECIFIC_INFO
custom_session_open_ssm: Option<i32>PB_OFFSET + MNM_CUSTOM_SESSION_OPEN_SSM
custom_session_close_ssm: Option<i32>PB_OFFSET + MNM_CUSTOM_SESSION_CLOSE_SSM
Implementations
Sourceimpl RequestTickBarUpdate
impl RequestTickBarUpdate
Sourcepub fn request(&self) -> Request
pub fn request(&self) -> Request
Returns the enum value of request, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_request(&mut self, value: Request)
pub fn set_request(&mut self, value: Request)
Sets request to the provided enum value.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn bar_type(&self) -> BarType
pub fn bar_type(&self) -> BarType
Returns the enum value of bar_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_bar_type(&mut self, value: BarType)
pub fn set_bar_type(&mut self, value: BarType)
Sets bar_type to the provided enum value.
Sourcepub fn bar_sub_type(&self) -> BarSubType
pub fn bar_sub_type(&self) -> BarSubType
Returns the enum value of bar_sub_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_bar_sub_type(&mut self, value: BarSubType)
pub fn set_bar_sub_type(&mut self, value: BarSubType)
Sets bar_sub_type to the provided enum value.
Sourcepub fn custom_session_open_ssm(&self) -> i32
pub fn custom_session_open_ssm(&self) -> i32
Returns the value of custom_session_open_ssm, or the default value if custom_session_open_ssm is unset.
Sourcepub fn custom_session_close_ssm(&self) -> i32
pub fn custom_session_close_ssm(&self) -> i32
Returns the value of custom_session_close_ssm, or the default value if custom_session_close_ssm is unset.
Sourcepub fn bar_type_specifier(&self) -> &str
pub fn bar_type_specifier(&self) -> &str
Returns the value of bar_type_specifier, or the default value if bar_type_specifier is unset.