pub struct RequestTimeBarUpdate {
pub template_id: i32,
pub user_msg: Vec<String>,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub request: Option<i32>,
pub bar_type: Option<i32>,
pub bar_type_period: Option<i32>,
}Expand description
PB_OFFSET = 100000, is the offset added for each MNM field id
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
user_msg: Vec<String>PB_OFFSET + MNM_USER_MSG
symbol: Option<String>PB_OFFSET + MNM_SYMBOL
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
request: Option<i32>PB_OFFSET + MNM_REQUEST
bar_type: Option<i32>PB_OFFSET + MNM_DATA_BAR_TYPE
bar_type_period: Option<i32>PB_OFFSET + MNM_TIME_BAR_PERIOD
Implementations
Sourceimpl RequestTimeBarUpdate
impl RequestTimeBarUpdate
Sourcepub fn request(&self) -> Request
pub fn request(&self) -> Request
Returns the enum value of request, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_request(&mut self, value: Request)
pub fn set_request(&mut self, value: Request)
Sets request to the provided enum value.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn bar_type_period(&self) -> i32
pub fn bar_type_period(&self) -> i32
Returns the value of bar_type_period, or the default value if bar_type_period is unset.
Sourcepub fn bar_type(&self) -> BarType
pub fn bar_type(&self) -> BarType
Returns the enum value of bar_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_bar_type(&mut self, value: BarType)
pub fn set_bar_type(&mut self, value: BarType)
Sets bar_type to the provided enum value.