pub struct ResponseDepthByOrderSnapshot {
pub template_id: i32,
pub user_msg: Vec<String>,
pub rq_handler_rp_code: Vec<String>,
pub rp_code: Vec<String>,
pub exchange: Option<String>,
pub symbol: Option<String>,
pub sequence_number: Option<u64>,
pub depth_side: Option<i32>,
pub depth_price: Option<f64>,
pub depth_size: Vec<i32>,
pub depth_order_priority: Vec<u64>,
pub exchange_order_id: Vec<String>,
}Expand description
PB_OFFSET = 100000, is the offset added for each MNM field id
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
user_msg: Vec<String>PB_OFFSET + MNM_USER_MSG
rq_handler_rp_code: Vec<String>PB_OFFSET + MNM_REQUEST_HANDLER_RESPONSE_CODE
rp_code: Vec<String>PB_OFFSET + MNM_RESPONSE_CODE
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
symbol: Option<String>PB_OFFSET + MNM_SYMBOL
sequence_number: Option<u64>PB_OFFSET + MNM_SEQUENCE_NUMBER
depth_side: Option<i32>PB_OFFSET + MNM_MARKET_DEPTH_SIDE
depth_price: Option<f64>PB_OFFSET + MNM_MARKET_DEPTH_PRICE
depth_size: Vec<i32>PB_OFFSET + MNM_MARKET_DEPTH_SIZE
depth_order_priority: Vec<u64>PB_OFFSET + MNM_MARKET_DEPTH_ORDER_PRIORITY
exchange_order_id: Vec<String>PB_OFFSET + MNM_EXCH_ORD_ID
Implementations
Sourceimpl ResponseDepthByOrderSnapshot
impl ResponseDepthByOrderSnapshot
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn sequence_number(&self) -> u64
pub fn sequence_number(&self) -> u64
Returns the value of sequence_number, or the default value if sequence_number is unset.
Sourcepub fn depth_side(&self) -> TransactionType
pub fn depth_side(&self) -> TransactionType
Returns the enum value of depth_side, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_depth_side(&mut self, value: TransactionType)
pub fn set_depth_side(&mut self, value: TransactionType)
Sets depth_side to the provided enum value.
Sourcepub fn depth_price(&self) -> f64
pub fn depth_price(&self) -> f64
Returns the value of depth_price, or the default value if depth_price is unset.