ResponseReferenceData

Struct ResponseReferenceData 

pub struct ResponseReferenceData {
Show 27 fields pub template_id: i32, pub user_msg: Vec<String>, pub rp_code: Vec<String>, pub presence_bits: Option<u32>, pub clear_bits: Option<u32>, pub symbol: Option<String>, pub exchange: Option<String>, pub exchange_symbol: Option<String>, pub symbol_name: Option<String>, pub trading_symbol: Option<String>, pub trading_exchange: Option<String>, pub product_code: Option<String>, pub instrument_type: Option<String>, pub underlying_symbol: Option<String>, pub expiration_date: Option<String>, pub currency: Option<String>, pub put_call_indicator: Option<String>, pub tick_size_type: Option<String>, pub price_display_format: Option<String>, pub is_tradable: Option<String>, pub is_underlying_for_binary_contrats: Option<String>, pub strike_price: Option<f64>, pub ftoq_price: Option<f64>, pub qtof_price: Option<f64>, pub min_qprice_change: Option<f64>, pub min_fprice_change: Option<f64>, pub single_point_value: Option<f64>,
}
presence bits defined here is also referred in response_get_instrument_by_underlying.proto and response_search_symbols.proto make sure both these proto files are always same.

Fields

template_id: i32user_msg: Vec<String>rp_code: Vec<String>presence_bits: Option<u32>clear_bits: Option<u32>symbol: Option<String>exchange: Option<String>exchange_symbol: Option<String>symbol_name: Option<String>trading_symbol: Option<String>trading_exchange: Option<String>product_code: Option<String>instrument_type: Option<String>underlying_symbol: Option<String>expiration_date: Option<String>currency: Option<String>put_call_indicator: Option<String>tick_size_type: Option<String>price_display_format: Option<String>is_tradable: Option<String>is_underlying_for_binary_contrats: Option<String>strike_price: Option<f64>ftoq_price: Option<f64>qtof_price: Option<f64>min_qprice_change: Option<f64>min_fprice_change: Option<f64>single_point_value: Option<f64>

Implementations

Source

impl ResponseReferenceData

pub fn symbol_name(&self) -> &str

Returns the value of symbol_name, or the default value if symbol_name is unset.

pub fn strike_price(&self) -> f64

Returns the value of strike_price, or the default value if strike_price is unset.

pub fn expiration_date(&self) -> &str

Returns the value of expiration_date, or the default value if expiration_date is unset.

pub fn put_call_indicator(&self) -> &str

Returns the value of put_call_indicator, or the default value if put_call_indicator is unset.

pub fn product_code(&self) -> &str

Returns the value of product_code, or the default value if product_code is unset.

pub fn underlying_symbol(&self) -> &str

Returns the value of underlying_symbol, or the default value if underlying_symbol is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn exchange_symbol(&self) -> &str

Returns the value of exchange_symbol, or the default value if exchange_symbol is unset.

pub fn instrument_type(&self) -> &str

Returns the value of instrument_type, or the default value if instrument_type is unset.

pub fn presence_bits(&self) -> u32

Returns the value of presence_bits, or the default value if presence_bits is unset.

pub fn tick_size_type(&self) -> &str

Returns the value of tick_size_type, or the default value if tick_size_type is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn ftoq_price(&self) -> f64

Returns the value of ftoq_price, or the default value if ftoq_price is unset.

pub fn qtof_price(&self) -> f64

Returns the value of qtof_price, or the default value if qtof_price is unset.

pub fn min_qprice_change(&self) -> f64

Returns the value of min_qprice_change, or the default value if min_qprice_change is unset.

pub fn min_fprice_change(&self) -> f64

Returns the value of min_fprice_change, or the default value if min_fprice_change is unset.

pub fn single_point_value(&self) -> f64

Returns the value of single_point_value, or the default value if single_point_value is unset.

pub fn price_display_format(&self) -> &str

Returns the value of price_display_format, or the default value if price_display_format is unset.

pub fn clear_bits(&self) -> u32

Returns the value of clear_bits, or the default value if clear_bits is unset.

pub fn is_tradable(&self) -> &str

Returns the value of is_tradable, or the default value if is_tradable is unset.

pub fn is_underlying_for_binary_contrats(&self) -> &str

Returns the value of is_underlying_for_binary_contrats, or the default value if is_underlying_for_binary_contrats is unset.

pub fn trading_symbol(&self) -> &str

Returns the value of trading_symbol, or the default value if trading_symbol is unset.

pub fn trading_exchange(&self) -> &str

Returns the value of trading_exchange, or the default value if trading_exchange is unset.