pub struct ResponseRithmicSystemInfo {
pub template_id: i32,
pub user_msg: Vec<String>,
pub rp_code: Vec<String>,
pub system_name: Vec<String>,
pub has_aggregated_quotes: Vec<bool>,
}Fields
template_id: i32user_msg: Vec<String>rp_code: Vec<String>system_name: Vec<String>has_aggregated_quotes: Vec<bool>Trait Implementations
Sourceimpl Clone for ResponseRithmicSystemInfo
impl Clone for ResponseRithmicSystemInfo
Sourcefn clone(&self) -> ResponseRithmicSystemInfo
fn clone(&self) -> ResponseRithmicSystemInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseRithmicSystemInfo
impl Debug for ResponseRithmicSystemInfo
Sourceimpl Default for ResponseRithmicSystemInfo
impl Default for ResponseRithmicSystemInfo
Sourceimpl Hash for ResponseRithmicSystemInfo
impl Hash for ResponseRithmicSystemInfo
Sourceimpl Message for ResponseRithmicSystemInfo
impl Message for ResponseRithmicSystemInfo
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl Eq for ResponseRithmicSystemInfo
impl StructuralPartialEq for ResponseRithmicSystemInfo