RithmicOrderNotification

Struct RithmicOrderNotification 

pub struct RithmicOrderNotification {
Show 49 fields pub template_id: i32, pub user_tag: Option<String>, pub notify_type: Option<i32>, pub is_snapshot: Option<bool>, pub status: Option<String>, pub basket_id: Option<String>, pub original_basket_id: Option<String>, pub linked_basket_ids: Option<String>, pub fcm_id: Option<String>, pub ib_id: Option<String>, pub user_id: Option<String>, pub account_id: Option<String>, pub symbol: Option<String>, pub exchange: Option<String>, pub trade_exchange: Option<String>, pub trade_route: Option<String>, pub exchange_order_id: Option<String>, pub instrument_type: Option<String>, pub completion_reason: Option<String>, pub quantity: Option<i32>, pub quan_release_pending: Option<i32>, pub price: Option<f64>, pub trigger_price: Option<f64>, pub transaction_type: Option<i32>, pub duration: Option<i32>, pub price_type: Option<i32>, pub orig_price_type: Option<i32>, pub manual_or_auto: Option<i32>, pub bracket_type: Option<i32>, pub avg_fill_price: Option<f64>, pub total_fill_size: Option<i32>, pub total_unfilled_size: Option<i32>, pub trail_by_ticks: Option<i32>, pub trail_by_price_id: Option<i32>, pub sequence_number: Option<String>, pub orig_sequence_number: Option<String>, pub cor_sequence_number: Option<String>, pub currency: Option<String>, pub country_code: Option<String>, pub text: Option<String>, pub report_text: Option<String>, pub remarks: Option<String>, pub window_name: Option<String>, pub originator_window_name: Option<String>, pub cancel_at_ssboe: Option<i32>, pub cancel_at_usecs: Option<i32>, pub cancel_after_secs: Option<i32>, pub ssboe: Option<i32>, pub usecs: Option<i32>,
}

Fields

template_id: i32user_tag: Option<String>notify_type: Option<i32>is_snapshot: Option<bool>status: Option<String>basket_id: Option<String>original_basket_id: Option<String>linked_basket_ids: Option<String>fcm_id: Option<String>ib_id: Option<String>user_id: Option<String>account_id: Option<String>symbol: Option<String>exchange: Option<String>trade_exchange: Option<String>trade_route: Option<String>exchange_order_id: Option<String>instrument_type: Option<String>completion_reason: Option<String>quantity: Option<i32>quan_release_pending: Option<i32>price: Option<f64>trigger_price: Option<f64>transaction_type: Option<i32>duration: Option<i32>price_type: Option<i32>orig_price_type: Option<i32>manual_or_auto: Option<i32>bracket_type: Option<i32>avg_fill_price: Option<f64>total_fill_size: Option<i32>total_unfilled_size: Option<i32>trail_by_ticks: Option<i32>trail_by_price_id: Option<i32>sequence_number: Option<String>orig_sequence_number: Option<String>cor_sequence_number: Option<String>currency: Option<String>country_code: Option<String>text: Option<String>report_text: Option<String>remarks: Option<String>window_name: Option<String>originator_window_name: Option<String>cancel_at_ssboe: Option<i32>cancel_at_usecs: Option<i32>cancel_after_secs: Option<i32>ssboe: Option<i32>usecs: Option<i32>

Implementations

Source

impl RithmicOrderNotification

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn instrument_type(&self) -> &str

Returns the value of instrument_type, or the default value if instrument_type is unset.

pub fn is_snapshot(&self) -> bool

Returns the value of is_snapshot, or the default value if is_snapshot is unset.

pub fn basket_id(&self) -> &str

Returns the value of basket_id, or the default value if basket_id is unset.

pub fn status(&self) -> &str

Returns the value of status, or the default value if status is unset.

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn avg_fill_price(&self) -> f64

Returns the value of avg_fill_price, or the default value if avg_fill_price is unset.

pub fn linked_basket_ids(&self) -> &str

Returns the value of linked_basket_ids, or the default value if linked_basket_ids is unset.

pub fn sequence_number(&self) -> &str

Returns the value of sequence_number, or the default value if sequence_number is unset.

pub fn transaction_type(&self) -> TransactionType

Returns the enum value of transaction_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_transaction_type(&mut self, value: TransactionType)

Sets transaction_type to the provided enum value.

pub fn quantity(&self) -> i32

Returns the value of quantity, or the default value if quantity is unset.

pub fn duration(&self) -> Duration

Returns the enum value of duration, or the default if the field is unset or set to an invalid enum value.

pub fn set_duration(&mut self, value: Duration)

Sets duration to the provided enum value.

pub fn price_type(&self) -> PriceType

Returns the enum value of price_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_price_type(&mut self, value: PriceType)

Sets price_type to the provided enum value.

pub fn trade_route(&self) -> &str

Returns the value of trade_route, or the default value if trade_route is unset.

pub fn trade_exchange(&self) -> &str

Returns the value of trade_exchange, or the default value if trade_exchange is unset.

pub fn quan_release_pending(&self) -> i32

Returns the value of quan_release_pending, or the default value if quan_release_pending is unset.

pub fn text(&self) -> &str

Returns the value of text, or the default value if text is unset.

pub fn report_text(&self) -> &str

Returns the value of report_text, or the default value if report_text is unset.

pub fn user_id(&self) -> &str

Returns the value of user_id, or the default value if user_id is unset.

pub fn exchange_order_id(&self) -> &str

Returns the value of exchange_order_id, or the default value if exchange_order_id is unset.

pub fn trigger_price(&self) -> f64

Returns the value of trigger_price, or the default value if trigger_price is unset.

pub fn orig_sequence_number(&self) -> &str

Returns the value of orig_sequence_number, or the default value if orig_sequence_number is unset.

pub fn cor_sequence_number(&self) -> &str

Returns the value of cor_sequence_number, or the default value if cor_sequence_number is unset.

pub fn completion_reason(&self) -> &str

Returns the value of completion_reason, or the default value if completion_reason is unset.

pub fn ssboe(&self) -> i32

Returns the value of ssboe, or the default value if ssboe is unset.

pub fn usecs(&self) -> i32

Returns the value of usecs, or the default value if usecs is unset.

pub fn notify_type(&self) -> NotifyType

Returns the enum value of notify_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_notify_type(&mut self, value: NotifyType)

Sets notify_type to the provided enum value.

pub fn account_id(&self) -> &str

Returns the value of account_id, or the default value if account_id is unset.

pub fn fcm_id(&self) -> &str

Returns the value of fcm_id, or the default value if fcm_id is unset.

pub fn ib_id(&self) -> &str

Returns the value of ib_id, or the default value if ib_id is unset.

pub fn total_fill_size(&self) -> i32

Returns the value of total_fill_size, or the default value if total_fill_size is unset.

pub fn total_unfilled_size(&self) -> i32

Returns the value of total_unfilled_size, or the default value if total_unfilled_size is unset.

pub fn user_tag(&self) -> &str

Returns the value of user_tag, or the default value if user_tag is unset.

pub fn country_code(&self) -> &str

Returns the value of country_code, or the default value if country_code is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn cancel_after_secs(&self) -> i32

Returns the value of cancel_after_secs, or the default value if cancel_after_secs is unset.

pub fn original_basket_id(&self) -> &str

Returns the value of original_basket_id, or the default value if original_basket_id is unset.

pub fn window_name(&self) -> &str

Returns the value of window_name, or the default value if window_name is unset.

pub fn originator_window_name(&self) -> &str

Returns the value of originator_window_name, or the default value if originator_window_name is unset.

pub fn manual_or_auto(&self) -> OrderPlacement

Returns the enum value of manual_or_auto, or the default if the field is unset or set to an invalid enum value.

pub fn set_manual_or_auto(&mut self, value: OrderPlacement)

Sets manual_or_auto to the provided enum value.

pub fn orig_price_type(&self) -> PriceType

Returns the enum value of orig_price_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_orig_price_type(&mut self, value: PriceType)

Sets orig_price_type to the provided enum value.

pub fn remarks(&self) -> &str

Returns the value of remarks, or the default value if remarks is unset.

pub fn trail_by_ticks(&self) -> i32

Returns the value of trail_by_ticks, or the default value if trail_by_ticks is unset.

pub fn trail_by_price_id(&self) -> i32

Returns the value of trail_by_price_id, or the default value if trail_by_price_id is unset.

pub fn cancel_at_ssboe(&self) -> i32

Returns the value of cancel_at_ssboe, or the default value if cancel_at_ssboe is unset.

pub fn cancel_at_usecs(&self) -> i32

Returns the value of cancel_at_usecs, or the default value if cancel_at_usecs is unset.

pub fn bracket_type(&self) -> BracketType

Returns the enum value of bracket_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_bracket_type(&mut self, value: BracketType)

Sets bracket_type to the provided enum value.