TradeStatistics

Struct TradeStatistics 

pub struct TradeStatistics {
Show 16 fields pub template_id: i32, pub symbol: Option<String>, pub exchange: Option<String>, pub presence_bits: Option<u32>, pub clear_bits: Option<u32>, pub is_snapshot: Option<bool>, pub open_price: Option<f64>, pub high_price: Option<f64>, pub low_price: Option<f64>, pub ssboe: Option<i32>, pub usecs: Option<i32>, pub source_ssboe: Option<i32>, pub source_usecs: Option<i32>, pub source_nsecs: Option<i32>, pub jop_ssboe: Option<i32>, pub jop_nsecs: Option<i32>,
}
PB_OFFSET = 100000, is the offset added for each MNM field id

Fields

template_id: i32

PB_OFFSET + MNM_TEMPLATE_ID

symbol: Option<String>

PB_OFFSET + MNM_SYMBOL

exchange: Option<String>

PB_OFFSET + MNM_EXCHANGE

presence_bits: Option<u32>

PB_OFFSET + MNM_PRICING_INDICATOR

clear_bits: Option<u32>

PB_OFFSET + MNM_DISPLAY_INDICATOR

is_snapshot: Option<bool>

PB_OFFSET + MNM_UPDATE_TYPE

open_price: Option<f64>

PB_OFFSET + MNM_OPEN_PRICE

high_price: Option<f64>

PB_OFFSET + MNM_HIGH_PRICE

low_price: Option<f64>

PB_OFFSET + MNM_LOW_PRICE

ssboe: Option<i32>

PB_OFFSET + MNM_SECONDS_SINCE_BOE

usecs: Option<i32>

PB_OFFSET + MNM_USECS

source_ssboe: Option<i32>

PB_OFFSET + MNM_SOURCE_SSBOE

source_usecs: Option<i32>

PB_OFFSET + MNM_SOURCE_USECS

source_nsecs: Option<i32>

PB_OFFSET + MNM_SOURCE_NSECS

jop_ssboe: Option<i32>

PB_OFFSET + MNM_JOP_SSBOE

jop_nsecs: Option<i32>

PB_OFFSET + MNM_JOP_NSECS

Implementations

Source

impl TradeStatistics

pub fn high_price(&self) -> f64

Returns the value of high_price, or the default value if high_price is unset.

pub fn low_price(&self) -> f64

Returns the value of low_price, or the default value if low_price is unset.

pub fn open_price(&self) -> f64

Returns the value of open_price, or the default value if open_price is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn is_snapshot(&self) -> bool

Returns the value of is_snapshot, or the default value if is_snapshot is unset.

pub fn presence_bits(&self) -> u32

Returns the value of presence_bits, or the default value if presence_bits is unset.

pub fn ssboe(&self) -> i32

Returns the value of ssboe, or the default value if ssboe is unset.

pub fn usecs(&self) -> i32

Returns the value of usecs, or the default value if usecs is unset.

pub fn source_ssboe(&self) -> i32

Returns the value of source_ssboe, or the default value if source_ssboe is unset.

pub fn source_usecs(&self) -> i32

Returns the value of source_usecs, or the default value if source_usecs is unset.

pub fn source_nsecs(&self) -> i32

Returns the value of source_nsecs, or the default value if source_nsecs is unset.

pub fn jop_ssboe(&self) -> i32

Returns the value of jop_ssboe, or the default value if jop_ssboe is unset.

pub fn jop_nsecs(&self) -> i32

Returns the value of jop_nsecs, or the default value if jop_nsecs is unset.

pub fn clear_bits(&self) -> u32

Returns the value of clear_bits, or the default value if clear_bits is unset.