pub struct UserAccountUpdate {
pub template_id: i32,
pub update_type: Option<i32>,
pub access_type: Option<i32>,
pub source_user_id: Option<String>,
pub user: Option<String>,
pub fcm_id: Option<String>,
pub ib_id: Option<String>,
pub account_id: Option<String>,
pub account_name: Option<String>,
pub ssboe: Option<i32>,
pub usecs: Option<i32>,
}Fields
template_id: i32update_type: Option<i32>access_type: Option<i32>source_user_id: Option<String>user: Option<String>fcm_id: Option<String>ib_id: Option<String>account_id: Option<String>account_name: Option<String>ssboe: Option<i32>usecs: Option<i32>Implementations
Sourceimpl UserAccountUpdate
impl UserAccountUpdate
Sourcepub fn access_type(&self) -> AccessType
pub fn access_type(&self) -> AccessType
Returns the enum value of access_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_access_type(&mut self, value: AccessType)
pub fn set_access_type(&mut self, value: AccessType)
Sets access_type to the provided enum value.
Sourcepub fn account_name(&self) -> &str
pub fn account_name(&self) -> &str
Returns the value of account_name, or the default value if account_name is unset.
Sourcepub fn account_id(&self) -> &str
pub fn account_id(&self) -> &str
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn fcm_id(&self) -> &str
pub fn fcm_id(&self) -> &str
Returns the value of fcm_id, or the default value if fcm_id is unset.
Sourcepub fn ib_id(&self) -> &str
pub fn ib_id(&self) -> &str
Returns the value of ib_id, or the default value if ib_id is unset.
Sourcepub fn source_user_id(&self) -> &str
pub fn source_user_id(&self) -> &str
Returns the value of source_user_id, or the default value if source_user_id is unset.
Sourcepub fn update_type(&self) -> UpdateType
pub fn update_type(&self) -> UpdateType
Returns the enum value of update_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_update_type(&mut self, value: UpdateType)
pub fn set_update_type(&mut self, value: UpdateType)
Sets update_type to the provided enum value.