#[non_exhaustive]pub enum FillHistoryRange {
#[non_exhaustive] Ssboe {
start: i32,
finish: i32,
},
#[non_exhaustive] TradeDate {
start: i32,
finish: i32,
},
}Expand description
The window of a fill-history request, in the two index formats template 3512 accepts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]Ssboe
Bounds are seconds since the beginning of the epoch.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]TradeDate
Bounds are trade dates written as CCYYMMDD, e.g. 20260804.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
Implementations
Sourceimpl FillHistoryRange
impl FillHistoryRange
Sourcepub fn ssboe(start: i32, finish: i32) -> Self
pub fn ssboe(start: i32, finish: i32) -> Self
A window bounded in seconds since the beginning of the epoch.
Sourcepub fn trade_date(start: i32, finish: i32) -> Self
pub fn trade_date(start: i32, finish: i32) -> Self
A window bounded by trade dates written as CCYYMMDD, e.g. 20260804.
Sourcepub fn index_format(&self) -> &'static str
pub fn index_format(&self) -> &'static str
The index_format spelling sent on the wire.