pub struct FrontMonthContractUpdate {
pub template_id: i32,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub is_front_month_symbol: Option<bool>,
pub symbol_name: Option<String>,
pub trading_symbol: Option<String>,
pub trading_exchange: Option<String>,
}Expand description
PB_OFFSET = 100000, is the offset added for each MNM field id
Fields
template_id: i32PB_OFFSET + MNM_TEMPLATE_ID
symbol: Option<String>PB_OFFSET + MNM_SYMBOL
exchange: Option<String>PB_OFFSET + MNM_EXCHANGE
is_front_month_symbol: Option<bool>PB_OFFSET + MNM_STATUS_INDICATOR
symbol_name: Option<String>PB_OFFSET + MNM_SYMBOL_NAME
trading_symbol: Option<String>PB_OFFSET + MNM_TRADING_SYMBOL
trading_exchange: Option<String>PB_OFFSET + MNM_TRADING_EXCHANGE
Implementations
Sourceimpl FrontMonthContractUpdate
impl FrontMonthContractUpdate
Sourcepub fn symbol_name(&self) -> &str
pub fn symbol_name(&self) -> &str
Returns the value of symbol_name, or the default value if symbol_name is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn is_front_month_symbol(&self) -> bool
pub fn is_front_month_symbol(&self) -> bool
Returns the value of is_front_month_symbol, or the default value if is_front_month_symbol is unset.
Sourcepub fn trading_symbol(&self) -> &str
pub fn trading_symbol(&self) -> &str
Returns the value of trading_symbol, or the default value if trading_symbol is unset.
Sourcepub fn trading_exchange(&self) -> &str
pub fn trading_exchange(&self) -> &str
Returns the value of trading_exchange, or the default value if trading_exchange is unset.