pub struct InstrumentPnLPositionUpdate {Show 33 fields
pub template_id: i32,
pub is_snapshot: Option<bool>,
pub fcm_id: Option<String>,
pub ib_id: Option<String>,
pub account_id: Option<String>,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub product_code: Option<String>,
pub instrument_type: Option<String>,
pub fill_buy_qty: Option<i32>,
pub fill_sell_qty: Option<i32>,
pub order_buy_qty: Option<i32>,
pub order_sell_qty: Option<i32>,
pub buy_qty: Option<i32>,
pub sell_qty: Option<i32>,
pub avg_open_fill_price: Option<f64>,
pub day_open_pnl: Option<f64>,
pub day_closed_pnl: Option<f64>,
pub day_pnl: Option<f64>,
pub day_open_pnl_offset: Option<f64>,
pub day_closed_pnl_offset: Option<f64>,
pub mtm_security: Option<String>,
pub open_long_options_value: Option<String>,
pub open_short_options_value: Option<String>,
pub closed_options_value: Option<String>,
pub option_cash_reserved: Option<String>,
pub open_position_pnl: Option<String>,
pub open_position_quantity: Option<i32>,
pub closed_position_pnl: Option<String>,
pub closed_position_quantity: Option<i32>,
pub net_quantity: Option<i32>,
pub ssboe: Option<i32>,
pub usecs: Option<i32>,
}Fields
template_id: i32is_snapshot: Option<bool>fcm_id: Option<String>ib_id: Option<String>account_id: Option<String>symbol: Option<String>exchange: Option<String>product_code: Option<String>instrument_type: Option<String>fill_buy_qty: Option<i32>fill_sell_qty: Option<i32>order_buy_qty: Option<i32>order_sell_qty: Option<i32>buy_qty: Option<i32>sell_qty: Option<i32>avg_open_fill_price: Option<f64>day_open_pnl: Option<f64>day_closed_pnl: Option<f64>day_pnl: Option<f64>day_open_pnl_offset: Option<f64>day_closed_pnl_offset: Option<f64>mtm_security: Option<String>open_long_options_value: Option<String>open_short_options_value: Option<String>closed_options_value: Option<String>option_cash_reserved: Option<String>open_position_pnl: Option<String>open_position_quantity: Option<i32>closed_position_pnl: Option<String>closed_position_quantity: Option<i32>net_quantity: Option<i32>ssboe: Option<i32>usecs: Option<i32>Implementations
Sourceimpl InstrumentPnLPositionUpdate
impl InstrumentPnLPositionUpdate
Sourcepub fn product_code(&self) -> &str
pub fn product_code(&self) -> &str
Returns the value of product_code, or the default value if product_code is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn instrument_type(&self) -> &str
pub fn instrument_type(&self) -> &str
Returns the value of instrument_type, or the default value if instrument_type is unset.
Sourcepub fn is_snapshot(&self) -> bool
pub fn is_snapshot(&self) -> bool
Returns the value of is_snapshot, or the default value if is_snapshot is unset.
Sourcepub fn account_id(&self) -> &str
pub fn account_id(&self) -> &str
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn fcm_id(&self) -> &str
pub fn fcm_id(&self) -> &str
Returns the value of fcm_id, or the default value if fcm_id is unset.
Sourcepub fn ib_id(&self) -> &str
pub fn ib_id(&self) -> &str
Returns the value of ib_id, or the default value if ib_id is unset.
Sourcepub fn order_buy_qty(&self) -> i32
pub fn order_buy_qty(&self) -> i32
Returns the value of order_buy_qty, or the default value if order_buy_qty is unset.
Sourcepub fn order_sell_qty(&self) -> i32
pub fn order_sell_qty(&self) -> i32
Returns the value of order_sell_qty, or the default value if order_sell_qty is unset.
Sourcepub fn fill_buy_qty(&self) -> i32
pub fn fill_buy_qty(&self) -> i32
Returns the value of fill_buy_qty, or the default value if fill_buy_qty is unset.
Sourcepub fn fill_sell_qty(&self) -> i32
pub fn fill_sell_qty(&self) -> i32
Returns the value of fill_sell_qty, or the default value if fill_sell_qty is unset.
Sourcepub fn buy_qty(&self) -> i32
pub fn buy_qty(&self) -> i32
Returns the value of buy_qty, or the default value if buy_qty is unset.
Sourcepub fn sell_qty(&self) -> i32
pub fn sell_qty(&self) -> i32
Returns the value of sell_qty, or the default value if sell_qty is unset.
Sourcepub fn mtm_security(&self) -> &str
pub fn mtm_security(&self) -> &str
Returns the value of mtm_security, or the default value if mtm_security is unset.
Sourcepub fn avg_open_fill_price(&self) -> f64
pub fn avg_open_fill_price(&self) -> f64
Returns the value of avg_open_fill_price, or the default value if avg_open_fill_price is unset.
Sourcepub fn open_position_pnl(&self) -> &str
pub fn open_position_pnl(&self) -> &str
Returns the value of open_position_pnl, or the default value if open_position_pnl is unset.
Sourcepub fn open_position_quantity(&self) -> i32
pub fn open_position_quantity(&self) -> i32
Returns the value of open_position_quantity, or the default value if open_position_quantity is unset.
Sourcepub fn closed_position_pnl(&self) -> &str
pub fn closed_position_pnl(&self) -> &str
Returns the value of closed_position_pnl, or the default value if closed_position_pnl is unset.
Sourcepub fn closed_position_quantity(&self) -> i32
pub fn closed_position_quantity(&self) -> i32
Returns the value of closed_position_quantity, or the default value if closed_position_quantity is unset.
Sourcepub fn net_quantity(&self) -> i32
pub fn net_quantity(&self) -> i32
Returns the value of net_quantity, or the default value if net_quantity is unset.
Sourcepub fn open_long_options_value(&self) -> &str
pub fn open_long_options_value(&self) -> &str
Returns the value of open_long_options_value, or the default value if open_long_options_value is unset.
Sourcepub fn open_short_options_value(&self) -> &str
pub fn open_short_options_value(&self) -> &str
Returns the value of open_short_options_value, or the default value if open_short_options_value is unset.
Sourcepub fn closed_options_value(&self) -> &str
pub fn closed_options_value(&self) -> &str
Returns the value of closed_options_value, or the default value if closed_options_value is unset.
Sourcepub fn option_cash_reserved(&self) -> &str
pub fn option_cash_reserved(&self) -> &str
Returns the value of option_cash_reserved, or the default value if option_cash_reserved is unset.
Sourcepub fn day_open_pnl(&self) -> f64
pub fn day_open_pnl(&self) -> f64
Returns the value of day_open_pnl, or the default value if day_open_pnl is unset.
Sourcepub fn day_closed_pnl(&self) -> f64
pub fn day_closed_pnl(&self) -> f64
Returns the value of day_closed_pnl, or the default value if day_closed_pnl is unset.
Sourcepub fn day_pnl(&self) -> f64
pub fn day_pnl(&self) -> f64
Returns the value of day_pnl, or the default value if day_pnl is unset.
Sourcepub fn day_open_pnl_offset(&self) -> f64
pub fn day_open_pnl_offset(&self) -> f64
Returns the value of day_open_pnl_offset, or the default value if day_open_pnl_offset is unset.
Sourcepub fn day_closed_pnl_offset(&self) -> f64
pub fn day_closed_pnl_offset(&self) -> f64
Returns the value of day_closed_pnl_offset, or the default value if day_closed_pnl_offset is unset.